@@ -3,24 +3,27 @@ package HTML::Perlinfo::General;
 use base qw(Exporter);
 our @EXPORT = qw(print_httpd print_thesemodules print_config print_variables print_general); 
 use POSIX qw(uname);
-use CGI::Deurl as => 'myparams';
 use Config qw(%Config config_sh);
 use Net::Domain qw(hostname);
+use CGI::Lite;
 use File::Spec;
 use HTML::Perlinfo::Common;
 use HTML::Perlinfo::Apache;
 
 # Should search for Get, Post, Cookies, Session, and Environment.
 sub perl_print_gpcse_array  {
+	  my $cgi = CGI::Lite->new();
 	  my $html;
 	  my($name) = @_;
 	  my ($gpcse_name, $gpcse_value);
-	  #POST names should be param() and get in url_param()
+	  #CGI.pm: POST names should be param() and get in url_param()
 	  if (defined($ENV{'QUERY_STRING'}) && length($ENV{'QUERY_STRING'}) >= 1) {
+	    my $myparams = $cgi->parse_form_data();
             foreach(keys %myparams) { $html .= print_table_row(2, "GET[\"$_\"]", $myparams{$_}); }
 	  }
 	  if (defined($ENV{'CONTENT_LENGTH'})) {
-             foreach(keys %myparams) { $html .= print_table_row(2, "POST[\"$_\"]", $myparams{$_}); }	     
+	    my $myparams = $cgi->parse_form_data();
+            foreach(keys %myparams) { $html .= print_table_row(2, "POST[\"$_\"]", $myparams{$_}); }	     
 	  }	  
           if (defined($ENV{'HTTP_COOKIE'})) {
              $cookies = $ENV{'HTTP_COOKIE'};
